@@ -2,7 +2,7 @@
 #
 #       cons.py
 #
-#       Copyright 2009-2013 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2014 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 import os, sys
 
 
-VERSION = "0.31.5"
+VERSION = "0.32.0"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
 if sys.platform.startswith("win"):
@@ -60,6 +60,10 @@ XDG_CURRENT_DESKTOP = 'XDG_CURRENT_DESKTOP'
 HAS_SYSTRAY = not (XDG_CURRENT_DESKTOP in os.environ and os.environ[XDG_CURRENT_DESKTOP] == "Unity")
 
 AVAILABLE_LANGS = ['default', 'cs', 'de', 'en', 'es', 'fr', 'it', 'nl', 'pl', 'pt_BR', 'ru', 'uk', 'zh_CN']
+COLOR_48_LINK_WEBS = "#00004444ffff"
+COLOR_48_LINK_NODE = "#071c838e071c"
+COLOR_48_LINK_FILE = "#8b8b69691414"
+COLOR_48_LINK_FOLD = "#7f7f7f7f7f7f"
 COLOR_48_YELLOW = "#bbbbbbbb0000"
 COLOR_48_WHITE = "#ffffffffffff"
 COLOR_48_BLACK = "#000000000000"
@@ -128,6 +132,7 @@ TABLE_DEFAULT_COL_MAX = 400
 
 CHAR_SPACE = " "
 CHAR_NEWLINE = "\n"
+CHAR_NEWPAGE = "\x0c"
 CHAR_CR = "\r"
 CHAR_TAB = "\t"
 CHAR_LISTBUL = "•"
@@ -191,12 +196,13 @@ STOCKS_N_FILES = [
 'color_foreground.png', 'format-text-large.png', 'format-text-large2.png', 'format-text-large3.png',
 'format-text-small.png', 'format-text-subscript.png', 'format-text-superscript.png', 'format-text-monospace.png',
 'format-text-strikethrough.png', 'format-text-underline.png', 'format-text-bold.png', 'format-text-italic.png',
-'format_text_latest.png', 'format_text.png', 'object-rotate-left.png', 'object-rotate-right.png',
+'format_text_latest.png', 'format_text_clear.png', 'format_text.png',
+'object-rotate-left.png', 'object-rotate-right.png',
 'to_pdf.png', 'to_txt.png', 'to_html.png', 'to_cherrytree.png', 'export_from_cherrytree.png', STR_STOCK_CT_IMP + '.png',
 'from_cherrytree.png', 'from_txt.png', 'cherrytree.png', 'quit-app.png',
 'new-instance.png', 'toolbar.png', 'cherries.png', 'tree-node-add.png',
 'tree-subnode-add.png', 'help-contents.png', 'index.png', 'timestamp.png',
-'horizontal_rule.png']
+'calendar.png', 'horizontal_rule.png']
 
 NODES_STOCKS = ['node_bullet', 'node_no_icon', 'cherry_black',
                 'cherry_blue', 'cherry_cyan', 'cherry_green',
@@ -419,9 +425,6 @@ UI_INFO = """
         <toolitem action='Save'/>
         <toolitem action='Export2PDF'/>
         <separator/>
-        <toolitem action='Undo'/>
-        <toolitem action='Redo'/>
-        <separator/>
         <toolitem action='FindInNodes'/>
         <separator/>
         <toolitem action='BulletedList'/>
@@ -434,6 +437,7 @@ UI_INFO = """
         <toolitem action='HandleLink'/>
         <toolitem action='HandleAnchor'/>
         <separator/>
+        <toolitem action='RemoveFormatting'/>
         <toolitem action='ColorForeground'/>
         <toolitem action='ColorBackground'/>
         <toolitem action='Bold'/>
@@ -560,7 +564,7 @@ def get_entries(inst):
     ( "InheritSyntax", "gtk-execute", _("_Inherit Syntax"), None, _("Change the Selected Node's Children Syntax Highlighting to the Father's Syntax Highlighting"), inst.node_inherit_syntax),
     ( "FormatLatest", "format_text_latest", _("Format _Latest"), "F7", _("Memory of Latest Text Format Type"), inst.apply_tag_latest),
     ( "PastePlainText", "edit-paste", _("_Paste as Plain Text"), "<control><shift>V", _("Paste as Plain Text, Discard the Rich Text Formatting"), inst.paste_as_plain_text),
-    ( "RemoveFormatting", "gtk-clear", _("_Remove Formatting"), "<control><shift>R", _("Remove the Formatting from the Selected Text"), inst.remove_text_formatting),
+    ( "RemoveFormatting", "format_text_clear", _("_Remove Formatting"), "<control><shift>R", _("Remove the Formatting from the Selected Text"), inst.remove_text_formatting),
     ( "ColorForeground", "color_foreground", _("Text _Color Foreground"), None, _("Change the Color of the Selected Text Foreground"), inst.apply_tag_foreground),
     ( "ColorBackground", "color_background", _("Text C_olor Background"), None, _("Change the Color of the Selected Text Background"), inst.apply_tag_background),
     ( "Bold", "format-text-bold", _("Toggle _Bold Property"), "<control>B", _("Toggle Bold Property of the Selected Text"), inst.apply_tag_bold),
@@ -613,7 +617,7 @@ def get_entries(inst):
     ( "FromTreepad", STR_STOCK_CT_IMP, _("From T_reepad Lite File"), None, _("Add Nodes of a Treepad Lite File to the Current Tree"), inst.nodes_add_from_treepad_file),
     ( "FromTuxCards", STR_STOCK_CT_IMP, _("From _TuxCards File"), None, _("Add Nodes of a TuxCards File to the Current Tree"), inst.nodes_add_from_tuxcards_file),
     ( "FromZim", STR_STOCK_CT_IMP, _("From _Zim Folder"), None, _("Add Nodes of a Zim Folder to the Current Tree"), inst.nodes_add_from_zim_folder),
-    ( "Help", "help-contents", _("Online _Manual"), None, _("Application's Online Manual"), inst.on_help_menu_item_activated),
+    ( "Help", "help-contents", _("Online _Manual"), "F1", _("Application's Online Manual"), inst.on_help_menu_item_activated),
     ( "CheckNewer", "gtk-network", _("_Check Newer Version"), None, _("Check for a Newer Version"), inst.check_for_newer_version),
     ( "About", "gtk-about", _("_About"), None, _("About CherryTree"), inst.dialog_about),
     ( "TableEditProp", "table_edit", _("_Edit Table Properties"), None, _("Edit the Table Properties"), inst.tables_handler.table_edit_properties),
@@ -644,6 +648,7 @@ def get_popup_menu_tree(inst):
     ("tree-subnode-add", _("Add _SubNode"), "<control><shift>N", _("Add a Child Node to the Selected Node"), inst.node_child_add),
     ("separator", None, None, None, None),
     ("cherry_edit", _("Change Node _Properties"), "F2", _("Edit the Properties of the Selected Node"), inst.node_edit),
+    ("calendar", _("Insert Today's Node"), "F8", _("Insert a Node with Hierarchy Year/Month/Day"), inst.node_date),
     ("gtk-info", _("Tree _Info"), None, _("Tree Summary Information"), inst.tree_info),
     ("separator", None, None, None, None),
     ("submenu-start", _("Node _Move"), "gtk-jump-to", None, None),
@@ -708,7 +713,7 @@ def get_popup_menu_entries_text(inst):
     ("separator", None, None, None, None),
     ("submenu-start", _("For_matting") , "format_text", None, None),
     ("format_text_latest", _("Format _Latest"), "F7", _("Memory of Latest Text Format Type"), inst.apply_tag_latest),
-    ("gtk-clear", _("_Remove Formatting"), "<control><shift>R", _("Remove the Formatting from the Selected Text"), inst.remove_text_formatting),
+    ("format_text_clear", _("_Remove Formatting"), "<control><shift>R", _("Remove the Formatting from the Selected Text"), inst.remove_text_formatting),
     ("separator", None, None, None, None),
     ("color_foreground", _("Text _Color Foreground"), None, _("Change the Color of the Selected Text Foreground"), inst.apply_tag_foreground),
     ("color_background", _("Text C_olor Background"), None, _("Change the Color of the Selected Text Background"), inst.apply_tag_background),
