@@ -2,7 +2,7 @@
 #
 #       exports.py
 #
-#       Copyright 2009-2013 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2014 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -104,7 +104,7 @@ class ExportPrint:
             self.dad.pick_dir = os.path.dirname(ret_filepath)
         return ret_filepath
 
-    def nodes_all_export_print(self, top_tree_iter, include_node_name):
+    def nodes_all_export_print(self, top_tree_iter, include_node_name, new_node_in_new_page):
         """Export Print All Nodes"""
         self.pango_text = []
         self.pixbuf_table_codebox_vector = []
@@ -112,13 +112,13 @@ class ExportPrint:
         if not top_tree_iter: tree_iter = self.dad.treestore.get_iter_first()
         else: tree_iter = top_tree_iter.copy()
         while tree_iter:
-            self.nodes_all_export_print_iter(tree_iter, include_node_name)
+            self.nodes_all_export_print_iter(tree_iter, include_node_name, new_node_in_new_page)
             if top_tree_iter: break
             tree_iter = self.dad.treestore.iter_next(tree_iter)
         self.dad.objects_buffer_refresh()
         self.run_print()
 
-    def nodes_all_export_print_iter(self, tree_iter, include_node_name):
+    def nodes_all_export_print_iter(self, tree_iter, include_node_name, new_node_in_new_page):
         """Export Print All Nodes - Iter"""
         self.dad.get_textbuffer_from_tree_iter(tree_iter)
         if self.dad.treestore[tree_iter][4] == cons.CUSTOM_COLORS_ID:
@@ -130,12 +130,17 @@ class ExportPrint:
         if include_node_name: self.pango_text_add_node_name(tree_iter, pango_text)
         if not self.pango_text: self.pango_text = pango_text
         else:
-            self.pango_text[-1] += cons.CHAR_NEWLINE*3 + pango_text[0]
-            if len(pango_text) > 1: self.pango_text += pango_text[1:]
+            if new_node_in_new_page:
+                pango_text[0] = 2*cons.CHAR_NEWPAGE + pango_text[0]
+                self.pango_text += pango_text
+                pixbuf_table_codebox_vector.insert(0, ["", [0, None, ""]])
+            else:
+                self.pango_text[-1] += cons.CHAR_NEWLINE*3 + pango_text[0]
+                if len(pango_text) > 1: self.pango_text += pango_text[1:]
         self.pixbuf_table_codebox_vector += pixbuf_table_codebox_vector
         child_tree_iter = self.dad.treestore.iter_children(tree_iter)
         while child_tree_iter:
-            self.nodes_all_export_print_iter(child_tree_iter, include_node_name)
+            self.nodes_all_export_print_iter(child_tree_iter, include_node_name, new_node_in_new_page)
             child_tree_iter = self.dad.treestore.iter_next(child_tree_iter)
 
     def pango_text_add_node_name(self, tree_iter, pango_text):
@@ -187,7 +192,7 @@ class Export2Txt:
 
     def prepare_txt_folder(self, new_folder):
         """Prepare the website folder"""
-        dir_place = support.dialog_folder_select(curr_folder=self.dad.file_dir, parent=self.dad.window)
+        dir_place = support.dialog_folder_select(curr_folder=self.dad.pick_dir, parent=self.dad.window)
         if dir_place == None: return False
         new_folder = support.clean_from_chars_not_for_filename(new_folder) + "_TXT"
         while os.path.exists(os.path.join(dir_place, new_folder)):
@@ -438,7 +443,7 @@ class Export2Html:
 
     def prepare_html_folder(self, new_folder):
         """Prepare the website folder"""
-        dir_place = support.dialog_folder_select(curr_folder=self.dad.file_dir, parent=self.dad.window)
+        dir_place = support.dialog_folder_select(curr_folder=self.dad.pick_dir, parent=self.dad.window)
         if dir_place == None: return False
         new_folder = support.clean_from_chars_not_for_filename(new_folder) + "_HTML"
         while os.path.exists(os.path.join(dir_place, new_folder)):
@@ -618,6 +623,7 @@ class Export2Html:
         for j, row in enumerate(table[1]['matrix']):
             table_html += "<tr>"
             for cell in row:
+                cell = cgi.escape(cell)
                 if j == 0: table_html += "<th>" + cell + "</th>"
                 else: table_html += "<td>" + cell + "</td>"
             table_html += "</tr>"
@@ -682,6 +688,7 @@ class Export2Html:
 
     def html_get_from_treestore_node(self, node_iter, sel_range=None):
         """Given a treestore iter returns the HTML rich text"""
+        #print "to html node", self.dad.treestore[node_iter][1]
         curr_buffer = self.dad.treestore[node_iter][2]
         pixbuf_table_codebox_vector = self.dad.state_machine.get_embedded_pixbufs_tables_codeboxes(curr_buffer,
                                                                                                    for_print=2,
@@ -817,7 +824,7 @@ class Export2Html:
                     vector = property_value.split()
                     if vector[0] == cons.LINK_TYPE_WEBS: href = vector[1]
                     elif vector[0] == cons.LINK_TYPE_FILE:
-                        href = "file://" + base64.b64decode(vector[1])
+                        href = "file://" + unicode(base64.b64decode(vector[1]), cons.STR_UTF8, cons.STR_IGNORE)
                     elif vector[0] == cons.LINK_TYPE_NODE:
                         dest_tree_iter = self.dad.get_tree_iter_from_node_id(long(vector[1]))
                         if not dest_tree_iter: continue
@@ -844,12 +851,15 @@ class Export2Html:
 
     def rgb_to_24(self, rgb_in):
         """Convert RRRRGGGGBBBB to RRGGBB if needed"""
+        if len(rgb_in) == 12:
+            r = int(rgb_in[:4], 16)
+            g = int(rgb_in[4:8], 16)
+            b = int(rgb_in[8:], 16)
+            r >>= 8
+            g >>= 8
+            b >>= 8
+            return "%.2x%.2x%.2x" % (r, g, b)
         if len(rgb_in) == 6: return rgb_in
-        # I expect len(rgb_in) == 12
-        r = int(rgb_in[:4], 16)
-        g = int(rgb_in[4:8], 16)
-        b = int(rgb_in[8:], 16)
-        r >>= 8
-        g >>= 8
-        b >>= 8
-        return "%.2x%.2x%.2x" % (r, g, b)
+        if len(rgb_in) == 3: return 2*rgb_in[0]+2*rgb_in[1]+2*rgb_in[2]
+        print "! rgb_to_24(%s)" % rgb_in
+        return rgb_in
