@@ -2,7 +2,7 @@
 #
 #       machines.py
 #
-#       Copyright 2009-2013 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2014 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -122,6 +122,7 @@ class XMLHandler:
         else: unique_id = self.dad.node_id_get()
         if dom_iter.hasAttribute('tags'): node_tags = dom_iter.attributes['tags'].value
         else: node_tags = ""
+        if node_tags: self.dad.tags_add_from_node(node_tags)
         if dom_iter.hasAttribute('readonly'): readonly = (dom_iter.attributes['readonly'].value == "True")
         else: readonly = False
         syntax_highlighting = dom_iter.attributes['prog_lang'].value
@@ -470,12 +471,8 @@ class XMLHandler:
             tag_name = tag.get_property("name")
             if tag_name and tag_name != cons.GTKSPELLCHECK_TAG_NAME:
                 if tag_name.startswith("weight_"): curr_attributes[cons.TAG_WEIGHT] = tag_name[7:]
-                elif tag_name.startswith("foreground_"):
-                    new_foreground = tag_name[11:]
-                    if new_foreground != cons.COLOR_48_BLACK: curr_attributes[cons.TAG_FOREGROUND] = new_foreground
-                elif tag_name.startswith("background_"):
-                    new_background = tag_name[11:]
-                    if new_background != cons.COLOR_48_WHITE: curr_attributes[cons.TAG_BACKGROUND] = new_background
+                elif tag_name.startswith("foreground_"): curr_attributes[cons.TAG_FOREGROUND] = tag_name[11:]
+                elif tag_name.startswith("background_"): curr_attributes[cons.TAG_BACKGROUND] = tag_name[11:]
                 elif tag_name.startswith("scale_"): curr_attributes[cons.TAG_SCALE] = tag_name[6:]
                 elif tag_name.startswith("justification_"): curr_attributes[cons.TAG_JUSTIFICATION] = tag_name[14:]
                 elif tag_name.startswith("style_"): curr_attributes[cons.TAG_STYLE] = tag_name[6:]
@@ -851,15 +848,23 @@ class StateMachine:
         """Update the state for the given node_id"""
         curr_index = self.nodes_indexes[node_id]
         last_index = len(self.nodes_vectors[node_id]) - 1
-        if curr_index != last_index: del self.nodes_vectors[node_id][curr_index+1:last_index+1]
+        if curr_index != last_index:
+            del self.nodes_vectors[node_id][curr_index+1:]
         xml_content = self.dad.xml_handler.treestore_node_to_dom(self.dad.curr_tree_iter)
         pixbuf_table_codebox_vector = self.get_embedded_pixbufs_tables_codeboxes(self.dad.curr_buffer)
         cursor_pos = self.dad.curr_buffer.get_property(cons.STR_CURSOR_POSITION)
         self.nodes_vectors[node_id].append([xml_content, pixbuf_table_codebox_vector, cursor_pos])
         num_saved_states = len(self.nodes_vectors[node_id])
-        if num_saved_states == 2: self.nodes_vectors[node_id][0][2] = cursor_pos
         while num_saved_states > self.dad.limit_undoable_steps:
             self.nodes_vectors[node_id].pop(0)
             num_saved_states -= 1
         self.nodes_indexes[node_id] = num_saved_states - 1
         self.nodes_indicators[node_id] = 0 # the current buffer state is saved
+
+    def update_curr_state_cursor_pos(self, node_id):
+        """If the buffer is still not modified update cursor pos"""
+        if not node_id in self.nodes_indexes: return
+        curr_index = self.nodes_indexes[node_id]
+        cursor_pos = self.dad.curr_buffer.get_property(cons.STR_CURSOR_POSITION)
+        self.nodes_vectors[node_id][curr_index][2] = cursor_pos
+        #print "SM UPD cursor_pos", cursor_pos
