@@ -2,7 +2,7 @@
 #
 #       printing.py
 #
-#       Copyright 2009-2013 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2014 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #       MA 02110-1301, USA.
 
 import gtk, gobject, pango, cairo
-import copy
+import copy, cgi
 import support, cons
 
 BOX_OFFSET = 4
@@ -98,6 +98,7 @@ class PrintHandler:
         while 1:
             exit_ok = True
             print_data.layout = []
+            print_data.forced_page_break = []
             print_data.layout_is_new_line = []
             print_data.layout_num_lines = []
             print_data.all_lines_y = []
@@ -106,7 +107,9 @@ class PrintHandler:
                 print_data.layout.append(context.create_pango_layout())
                 print_data.layout[-1].set_font_description(self.pango_font)
                 print_data.layout[-1].set_width(int(self.page_width*pango.SCALE))
-                print_data.layout[-1].set_markup(text_slot)
+                is_forced_page_break = text_slot.startswith(2*cons.CHAR_NEWPAGE)
+                print_data.forced_page_break.append(is_forced_page_break)
+                print_data.layout[-1].set_markup(text_slot if not is_forced_page_break else text_slot[2:])
                 if text_slot == cons.CHAR_NEWLINE:
                     print_data.layout_is_new_line.append(True) # in other case we detect the newline from a following line
                 else: print_data.layout_is_new_line.append(False) # but here we have a single layout line
@@ -119,6 +122,10 @@ class PrintHandler:
             for i, layout in enumerate(print_data.layout):
                 #print "layout", i
                 # text
+                if print_data.forced_page_break[i] and curr_y > 0:
+                    #print "forced_page_break"
+                    print_data.page_breaks.append(inline_starter)
+                    curr_y = 0;
                 layout_line_idx = 0
                 while layout_line_idx < print_data.layout_num_lines[i]:
                     #print "layout_line_idx", layout_line_idx
@@ -308,6 +315,7 @@ class PrintHandler:
             for j, cell_text in enumerate(table_row):
                 layout = context.create_pango_layout()
                 layout.set_font_description(self.pango_font)
+                cell_text = cgi.escape(cell_text)
                 if i == 0: cell_text = "<b>" + cell_text + "</b>"
                 layout.set_width(int(table['col_max']*pango.SCALE))
                 layout.set_wrap(pango.WRAP_WORD_CHAR)
