@@ -2,7 +2,7 @@
 #
 #       support.py
 #
-#       Copyright 2009-2013 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2014 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -267,7 +267,7 @@ def dialog_about(dad):
     dialog = gtk.AboutDialog()
     dialog.set_program_name("CherryTree")
     dialog.set_version(cons.VERSION)
-    dialog.set_copyright(_("""Copyright © 2009-2013
+    dialog.set_copyright(_("""Copyright © 2009-2014
 Giuseppe Penone <giuspen@gmail.com>"""))
     dialog.set_comments(_("A Hierarchical Note Taking Application, featuring Rich Text and Syntax Highlighting"))
     dialog.set_license(_("""
@@ -309,59 +309,59 @@ Ukrainian (uk) Andriy Kovtun <kovtunos@yandex.ru>"""))
     dialog.run()
     dialog.hide()
 
-def dialog_anchors_list(father_win, title, anchors_list):
-    """List Anchors in a Node"""
-    class AnchorParms:
+def dialog_choose_element_in_list(father_win, title, elements_list, column_title):
+    """Choose Between Elements in List"""
+    class ListParms:
         def __init__(self):
             self.sel_iter = None
-    anchor_parms = AnchorParms()
+    list_parms = ListParms()
     dialog = gtk.Dialog(title=title,
         parent=father_win,
         flags=gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
         buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
                  gtk.STOCK_OK, gtk.RESPONSE_ACCEPT) )
     dialog.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
-    dialog.set_default_size(300, 200)
+    dialog.set_default_size(400, 200)
     scrolledwindow = gtk.ScrolledWindow()
     scrolledwindow.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-    anchors_liststore = gtk.ListStore(str)
-    anchors_treeview = gtk.TreeView(anchors_liststore)
-    anchors_renderer_text = gtk.CellRendererText()
-    anchors_column = gtk.TreeViewColumn(_("Anchor Name"), anchors_renderer_text, text=0)
-    anchors_treeview.append_column(anchors_column)
-    anchors_treeviewselection = anchors_treeview.get_selection()
-    for anchor_element in anchors_list:
-        anchors_liststore.append(anchor_element)
-    scrolledwindow.add(anchors_treeview)
-    anchor_parms.sel_iter = anchors_liststore.get_iter_first()
-    if anchor_parms.sel_iter:
-        anchors_treeview.set_cursor(anchors_liststore.get_path(anchor_parms.sel_iter))
+    elements_liststore = gtk.ListStore(str)
+    elements_treeview = gtk.TreeView(elements_liststore)
+    elements_renderer_text = gtk.CellRendererText()
+    elements_column = gtk.TreeViewColumn(column_title, elements_renderer_text, text=0)
+    elements_treeview.append_column(elements_column)
+    elements_treeviewselection = elements_treeview.get_selection()
+    for element_name in elements_list:
+        elements_liststore.append(element_name)
+    scrolledwindow.add(elements_treeview)
+    list_parms.sel_iter = elements_liststore.get_iter_first()
+    if list_parms.sel_iter:
+        elements_treeview.set_cursor(elements_liststore.get_path(list_parms.sel_iter))
     content_area = dialog.get_content_area()
     content_area.pack_start(scrolledwindow)
-    def on_mouse_button_clicked_anchors_list(widget, event):
+    def on_mouse_button_clicked_elements_list(widget, event):
         if event.button != 1: return
         if event.type == gtk.gdk._2BUTTON_PRESS:
             try: dialog.get_widget_for_response(gtk.RESPONSE_ACCEPT).clicked()
             except: print cons.STR_PYGTK_222_REQUIRED
     def on_treeview_event_after(treeview, event):
         if event.type not in [gtk.gdk.BUTTON_PRESS, gtk.gdk.KEY_PRESS]: return
-        model, anchor_parms.sel_iter = anchors_treeviewselection.get_selected()
-    def on_key_press_anchorslistdialog(widget, event):
+        model, list_parms.sel_iter = elements_treeviewselection.get_selected()
+    def on_key_press_elementslistdialog(widget, event):
         keyname = gtk.gdk.keyval_name(event.keyval)
         if keyname == cons.STR_RETURN:
             try: dialog.get_widget_for_response(gtk.RESPONSE_ACCEPT).clicked()
             except: print cons.STR_PYGTK_222_REQUIRED
             return True
         return False
-    anchors_treeview.connect('event-after', on_treeview_event_after)
-    dialog.connect('key_press_event', on_key_press_anchorslistdialog)
-    anchors_treeview.connect('button-press-event', on_mouse_button_clicked_anchors_list)
+    elements_treeview.connect('event-after', on_treeview_event_after)
+    dialog.connect('key_press_event', on_key_press_elementslistdialog)
+    elements_treeview.connect('button-press-event', on_mouse_button_clicked_elements_list)
     content_area.show_all()
-    anchors_treeview.grab_focus()
+    elements_treeview.grab_focus()
     response = dialog.run()
     dialog.hide()
-    if response != gtk.RESPONSE_ACCEPT or not anchor_parms.sel_iter: return ""
-    return unicode(anchors_liststore[anchor_parms.sel_iter][0], cons.STR_UTF8, cons.STR_IGNORE)
+    if response != gtk.RESPONSE_ACCEPT or not list_parms.sel_iter: return ""
+    return unicode(elements_liststore[list_parms.sel_iter][0], cons.STR_UTF8, cons.STR_IGNORE)
 
 def dialog_img_n_entry(father_win, title, entry_content, img_stock):
     """Insert/Edit Anchor Name"""
@@ -411,7 +411,7 @@ def dialog_image_handle(father_win, title, original_pixbuf):
         buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
                  gtk.STOCK_OK, gtk.RESPONSE_ACCEPT) )
     dialog.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
-    dialog.set_default_size(600, 600)
+    dialog.set_default_size(600, 500)
     button_rotate_90_ccw = gtk.Button()
     button_rotate_90_ccw.set_image(gtk.image_new_from_stock("object-rotate-left", gtk.ICON_SIZE_DND))
     button_rotate_90_cw = gtk.Button()
@@ -594,7 +594,7 @@ def dialog_link_handle(dad, title, sel_tree_iter):
         buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
         gtk.STOCK_OK, gtk.RESPONSE_ACCEPT) )
     dialog.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
-    dialog.set_default_size(500, 400)
+    dialog.set_default_size(600, 500)
     
     hbox_webs = gtk.HBox()
     image_webs = gtk.Image()
@@ -756,7 +756,7 @@ def dialog_link_handle(dad, title, sel_tree_iter):
         if not anchors_list:
             dialog_info(_("There are No Anchors in the Selected Node"), dialog)
             return
-        ret_anchor_name = dialog_anchors_list(dialog, _("Choose Existing Anchor"), anchors_list)
+        ret_anchor_name = dialog_choose_element_in_list(dialog, _("Choose Existing Anchor"), anchors_list, _("Anchor Name"))
         if ret_anchor_name: entry_anchor.set_text(ret_anchor_name)
     def on_treeview_event_after(treeview, event):
         if event.type not in [gtk.gdk.BUTTON_PRESS, gtk.gdk.KEY_PRESS]: return
@@ -801,7 +801,7 @@ def dialog_choose_node(father_win, title, treestore, sel_tree_iter):
         buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
         gtk.STOCK_OK, gtk.RESPONSE_ACCEPT) )
     dialog.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
-    dialog.set_default_size(400, 300)
+    dialog.set_default_size(600, 500)
     treeview_2 = gtk.TreeView(treestore)
     treeview_2.set_headers_visible(False)
     renderer_pixbuf_2 = gtk.CellRendererPixbuf()
@@ -845,10 +845,10 @@ def dialog_choose_node(father_win, title, treestore, sel_tree_iter):
     dialog.hide()
     return None if response != gtk.RESPONSE_ACCEPT else node_parms.sel_iter
 
-def dialog_selnode_selnodeandsub_alltree(father_win, also_selection, also_node_name=False):
+def dialog_selnode_selnodeandsub_alltree(dad, also_selection, also_include_node_name=False, also_new_node_page=False):
     """Dialog to select between the Selected Node/Selected Node + Subnodes/All Tree"""
     dialog = gtk.Dialog(title=_("Involved Nodes"),
-        parent=father_win,
+        parent=dad.window,
         flags=gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
         buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
         gtk.STOCK_OK, gtk.RESPONSE_ACCEPT) )
@@ -859,19 +859,22 @@ def dialog_selnode_selnodeandsub_alltree(father_win, also_selection, also_node_n
     radiobutton_alltree = gtk.RadioButton(label=_("All the Tree"))
     radiobutton_selnodeandsub.set_group(radiobutton_selnode)
     radiobutton_alltree.set_group(radiobutton_selnode)
-    if also_node_name:
-        separator_item = gtk.HSeparator()
-        checkbutton_node_name = gtk.CheckButton(label=_("Include Node Name"))
-        checkbutton_node_name.set_active(True)
     if also_selection: radiobutton_selection.set_group(radiobutton_selnode)
     content_area = dialog.get_content_area()
     if also_selection: content_area.pack_start(radiobutton_selection)
     content_area.pack_start(radiobutton_selnode)
     content_area.pack_start(radiobutton_selnodeandsub)
     content_area.pack_start(radiobutton_alltree)
-    if also_node_name:
+    if also_include_node_name:
+        separator_item = gtk.HSeparator()
+        checkbutton_node_name = gtk.CheckButton(label=_("Include Node Name"))
+        checkbutton_node_name.set_active(dad.last_include_node_name)
         content_area.pack_start(separator_item)
         content_area.pack_start(checkbutton_node_name)
+    if also_new_node_page:
+        checkbutton_new_node_page = gtk.CheckButton(label=_("New Node in New Page"))
+        checkbutton_new_node_page.set_active(dad.last_new_node_page)
+        content_area.pack_start(checkbutton_new_node_page)
     def on_key_press_enter_dialog(widget, event):
         if gtk.gdk.keyval_name(event.keyval) == cons.STR_RETURN:
             try: dialog.get_widget_for_response(gtk.RESPONSE_ACCEPT).clicked()
@@ -885,11 +888,13 @@ def dialog_selnode_selnodeandsub_alltree(father_win, also_selection, also_node_n
     elif radiobutton_selnodeandsub.get_active(): ret_val = 2
     elif radiobutton_alltree.get_active(): ret_val = 3
     else: ret_val = 4
-    if also_node_name and checkbutton_node_name.get_active(): ret_node_name = True
-    else: ret_node_name = False
+    if also_include_node_name:
+        dad.last_include_node_name = checkbutton_node_name.get_active()
+    if also_new_node_page:
+        dad.last_new_node_page = checkbutton_new_node_page.get_active()
     dialog.destroy()
     if response != gtk.RESPONSE_ACCEPT: ret_val = 0
-    return [ret_val, ret_node_name]
+    return ret_val
 
 def set_bookmarks_menu_items(inst):
     """Set Bookmarks Menu Items"""
